change_api_url: Change API root URL

View source: R/services.R

change_api_urlR Documentation

Change API root URL

Description

Changes the base URL used by the package to connect to a compatible statistics API. This allows switching between ISTAC, IBESTAT and any other institution implementing the same API.

Usage

change_api_url(api_root_url)

Arguments

api_root_url

Character string with the base URL of the target API.

Value

The configured API root URL.

Examples

change_api_url("https://datos.canarias.es/api/estadisticas/")


istacr documentation built on July 10, 2026, 1:08 a.m.