Learn R Programming

istacr (version 0.2.2)

get_statisticalresources_datasets_agency_resource: Get datasets (agencyID / resourceID)

Description

This function allows to obtain all the versions of a statistical cube with a certain identifier and that also maintains a certain organization.

Usage

get_statisticalresources_datasets_agency_resource(
  agencyid,
  resourceid,
  lang = "es",
  limit = 25,
  offset = 0,
  orderby = "",
  query = ""
)

Arguments

agencyid

(string): Identifier of the maintainer organization of the resource. A possible value is ``ISTAC``.

resourceid

(string): Resource identifier. A possible value is ``C00010A_000002``.

lang

(string): Language in which you want to get the answer.

limit

(int): Results limit. By default ``limit=25``.

offset

(int): Displacement. Result from which it is returned. By default ``offset=0``.

orderby

(string): Order. Possible values are ``ID ASC`` or ``ID DESC``.

query

(string): Metadata query on which the searches can be built.

Examples

Run this code
get_statisticalresources_datasets_agency_resource(
agencyid="ISTAC",
resourceid="C00010A_000002"
)

Run the code above in your browser using DataLab