get_statisticalresources_datasets_agency_resource_version: Get datasets (agencyID / resourceID / version)

View source: R/statistical-resources-cubes.R

get_statisticalresources_datasets_agency_resource_versionR Documentation

Get datasets (agencyID / resourceID / version)

Description

This function allows to obtain a certain version of a statistical cube with a certain identifier and that also maintains a certain organization.

Usage

get_statisticalresources_datasets_agency_resource_version(
  agencyid,
  resourceid,
  version,
  dim = "",
  representation = "",
  granularity = "",
  fields = "",
  lang = "es",
  as_dataframe = T
)

Arguments

agencyid

(string): Identifier of the maintainer organization of the resource. A possible value is ISTAC.

resourceid

(string): Resource identifier. A possible value is C00010A_000002.

version

(string): Resource version. A possible value is 001.000.

dim

(string): Allows filtering the data obtained in the response. An example is TIME_PERIOD:2009|2010.

representation

(string): Specifies the representation format of the returned data. Leave empty to use the API default.

granularity

(string): Specifies the desired level of aggregation or granularity for the returned data. Leave empty to use the API default.

fields

(string): Allows you to customize the response by excluding fields from it. The possible values are -metadata and -data.

lang

(string): Language in which you want to get the answer.

as_dataframe

(bool): If TRUE, this function returns a list with:

  • dataframe: data.frame built from the API response.

  • codelists: mapping between codes and representations for each column.

Examples

get_statisticalresources_datasets_agency_resource_version(
  agencyid = "ISTAC",
  resourceid = "E68025A_000007",
  version = "~latest",
  representation = "TIME_PERIOD[~last=1]:MEDIDAS[CASO_ACTIVO]:TERRITORIO[ES70]")$dataframe


istacr documentation built on July 10, 2026, 1:08 a.m.