Learn R Programming

istacr (version 0.2.2)

get_statisticalresources_queries: Get queries

Description

This function allows consulting all existing statistical queries.

Usage

get_statisticalresources_queries(
  lang = "es",
  limit = 25,
  offset = 0,
  orderby = "",
  query = ""
)

Arguments

lang

(string): Language in which you want to get the answer.

limit

(int): Results limit. By default ``limit=25``.

offset

(int): Displacement. Result from which it is returned. By default ``offset=0``.

orderby

(string): Order. Possible values are ``ID ASC`` or ``ID DESC``,

query

(string): Metadata query on which the searches can be built.

Examples

Run this code
get_statisticalresources_queries(limit=5)

Run the code above in your browser using DataLab