(string): Identifier of the maintainer organization of the resource. A possible value is ``ISTAC``.
resourceid
(string): Resource identifier. A possible value is ``C00005A_000004``.
fields
(string): Allows you to customize the response by excluding fields from it.
- The possible values are ``-metadata`` and ``-data``.
lang
(string): Language in which you want to get the answer.
as_dataframe
(bool): If True, this function returns a namedtuple with:
- dataframe: pandas dataframe built from API response.
- codelists: mapping between codes and representations for each column.