get_structuralresources_codelists_agency_resource: Get codelists agency resource
Description
This function allows to obtain all the versions of a classification with a certain
identifier and that is also kept by a certain organization.
Usage
get_structuralresources_codelists_agency_resource(
agencyid,
resourceid,
limit = 25,
offset = 0,
query = "",
orderby = ""
)
Arguments
- agencyid
(string): Agency identificator.
- resourceid
(string): Resource identificator.
- limit
(int): Results limit. By default ``limit = 25``.
- offset
(int): Displacement. Result from which it is returned. By default ``offset = 0``.
- query
(string): Query to filter the results.
- orderby
(string): Field by which to sort the results.
Examples
Run this codeget_structuralresources_codelists_agency_resource("ISTAC", "CL_AREA_ES")
Run the code above in your browser using DataLab