Learn R Programming

istacr (version 0.2.2)

get_structuralresources_codelists_agency_resource_version_codes: Get codelists agency resource version codes

Description

This function allows to consult the codes of a version of a classification. Note that if wildcards are used as ``~all`` or one of the ``limit``, ``offset``, ``query`` or ``orderBy`` parameters, the list will be automatically paginated.

Usage

get_structuralresources_codelists_agency_resource_version_codes(
  agencyid,
  resourceid,
  version,
  limit = 25,
  offset = 0,
  query = "",
  orderby = "",
  openness = "",
  order = "",
  fields = ""
)

Arguments

agencyid

(string): Agency identificator.

resourceid

(string): Resource identificator.

version

(string): Specific resource version.

limit

(int): Results limit. By default ``limit = 25``.

offset

(int): Displacement. Result from which it is returned. By default ``offset = 0``.

query

(string): Query to filter the results. orderby (string): Field by which to sort the results.

orderby

(string): Order established for data.

openness

(string): Opening established for viewing.

order

(string): Order established for visualization.

fields

(string): Additional fields that you want to show in the answer.

Examples

Run this code
get_structuralresources_codelists_agency_resource_version_codes(
"ISTAC",
"CL_AREA_ES",
"01.000"
)

Run the code above in your browser using DataLab