get_structuralresources_codelists_agency_resource_version_restrictions: Get codelists agency resource version restrictions

get_structuralresources_codelists_agency_resource_version_restrictionsR Documentation

Get codelists agency resource version restrictions

Description

This function allows you to consult any restrictions for a specific code of a version of a classification.

Usage

get_structuralresources_codelists_agency_resource_version_restrictions(
  agencyid,
  resourceid,
  version
)

Arguments

agencyid

(string): Agency identificator.

resourceid

(string): Resource identificator.

version

(string): Specific resource version.

Examples

get_structuralresources_codelists_agency_resource_version_restrictions(
"ISTAC",
"CL_AREA_ES",
"~latest"
)

istacr documentation built on July 10, 2026, 1:08 a.m.