| change_api_url | R Documentation |
Changes the base URL used by the package to connect to a compatible statistics API. This allows switching between ISTAC, IBESTAT and any other institution implementing the same API.
change_api_url(api_root_url)
api_root_url |
Character string with the base URL of the target API. |
The configured API root URL.
change_api_url("https://datos.canarias.es/api/estadisticas/")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.