get_statisticalresources_datasets_agency: Get datasets (agencyID)
Description
This function allows to consult all the data sets maintained by a certain organization.
Usage
get_statisticalresources_datasets_agency(
agencyid,
lang = "es",
limit = 25,
offset = 0,
orderby = "",
query = ""
)
Arguments
- agencyid
(string): Identifier of the maintainer organization of the resource. A possible value is ``ISTAC``.
- lang
(string): Language in which you want to get the answer.
- limit
(int): Results limit. By default ``limit=25``.
- offset
(int): Displacement. Result from which it is returned. By default ``offset=0``.
- orderby
(string): Order. Possible values are ``ID ASC`` or ``ID DESC``.
- query
(string): Metadata query on which the searches can be built.
Examples
Run this codeget_statisticalresources_datasets_agency(agencyid="ISTAC")
Run the code above in your browser using DataLab