View source: R/statistical-resources-cubes.R
| get_statisticalresources_datasets_agency_resource_version | R Documentation |
This function allows to obtain a certain version of a statistical cube with a certain identifier and that also maintains a certain organization.
get_statisticalresources_datasets_agency_resource_version(
agencyid,
resourceid,
version,
dim = "",
representation = "",
granularity = "",
fields = "",
lang = "es",
as_dataframe = T
)
agencyid |
(string): Identifier of the maintainer organization of the resource. A possible value is |
resourceid |
(string): Resource identifier. A possible value is |
version |
(string): Resource version. A possible value is |
dim |
(string): Allows filtering the data obtained in the response. An example is |
representation |
(string): Specifies the representation format of the returned data. Leave empty to use the API default. |
granularity |
(string): Specifies the desired level of aggregation or granularity for the returned data. Leave empty to use the API default. |
fields |
(string): Allows you to customize the response by excluding fields from it. The possible values are |
lang |
(string): Language in which you want to get the answer. |
as_dataframe |
(bool): If TRUE, this function returns a list with:
|
get_statisticalresources_datasets_agency_resource_version(
agencyid = "ISTAC",
resourceid = "E68025A_000007",
version = "~latest",
representation = "TIME_PERIOD[~last=1]:MEDIDAS[CASO_ACTIVO]:TERRITORIO[ES70]")$dataframe
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.