get_statisticalresources_datasets_agency_resource_version: Get datasets (agencyID / resourceID / version)
Description
This function allows to obtain a certain version of a statistical cube with a certain
identifier and that also maintains a certain organization.
Usage
get_statisticalresources_datasets_agency_resource_version(
agencyid,
resourceid,
version,
dim = "",
fields = "",
lang = "es",
as_dataframe = F
)
Arguments
agencyid
(string): Identifier of the maintainer organization of the resource. A possible value is ``ISTAC``.
resourceid
(string): Resource identifier. A possible value is ``C00010A_000002``.
version
(string): Resource version. A possible value is ``001.000``.
dim
(string): Allows filtering the data obtained in the response. A example is ``TIME_PERIOD:2009|2010``.
fields
(string): Allows you to customize the response by excluding fields from it. The possible values are ``-metadata`` and ``-data``.
lang
(string): Language in which you want to get the answer.
as_dataframe
(bool): If True, this function returns a namedtuple with:
- dataframe: pandas dataframe built from API response.
- codelists: mapping between codes and representations for each column.